@@ -1,18 +1,26 @@
 
-# $Id: UK.pm,v 2.2 2008/09/29 02:23:39 Martin Exp $
+# $Id: UK.pm,v 2.4 2010-03-31 03:37:13 Martin Exp $
 
 =head1 NAME
 
 WWW::Search::Ebay::UK - backend for searching auctions at www.ebay.co.uk
 
+=head1 SYNOPSIS
+
+  use WWW::Search;
+  my $oSearch = new WWW::Search('Ebay::UK');
+  my $sQuery = WWW::Search::escape_query("Yakface");
+  $oSearch->native_query($sQuery);
+  while (my $oResult = $oSearch->next_result())
+    { print $oResult->url, "\n"; }
+
 =head1 DESCRIPTION
 
 Acts just like WWW::Search::Ebay.
 
 =head1 AUTHOR
 
-C<WWW::Search::Ebay::UK> was written by and is maintained by
-Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
@@ -24,7 +32,7 @@ use warnings;
 use Carp;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.2 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.4 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _native_setup_search
   {
@@ -72,7 +80,7 @@ sub _columns
   {
   my $self = shift;
   # This is for UK:
-  return qw( paypal bids price postage enddate );
+  return qw( seller paypal bids price postage enddate );
   } # _columns
 
 1;
